/// <reference types="hoist-non-react-statics" />
/**
 * 用来显示选择结果，垂直显示。支持移出、排序等操作。
 */
import React from 'react';
import Sortable from 'sortablejs';
import { Option, Options } from './Select';
import { ThemeProps } from '../theme';
import { LocaleProps } from '../locale';
import { BaseSelectionProps } from './Selection';
export interface ResultListProps extends ThemeProps, LocaleProps, BaseSelectionProps {
    className?: string;
    value?: Array<Option>;
    onChange?: (value: Array<Option>, optionModified?: boolean) => void;
    sortable?: boolean;
    disabled?: boolean;
    title?: string;
    placeholder: string;
    itemRender: (option: Option, states: ItemRenderStates) => JSX.Element;
    itemClassName?: string;
    columns: Array<{
        name: string;
        label: string;
        [propName: string]: any;
    }>;
    cellRender?: (column: {
        name: string;
        label: string;
        [propName: string]: any;
    }, option: Option, colIndex: number, rowIndex: number) => JSX.Element;
    searchable?: boolean;
    onSearch?: Function;
}
export interface ItemRenderStates {
    index: number;
    disabled?: boolean;
    onChange: (value: any, name: string) => void;
}
interface ResultListState {
    searchResult: Options | null;
}
export declare class ResultList extends React.Component<ResultListProps, ResultListState> {
    static itemRender(option: any): JSX.Element;
    static defaultProps: Pick<ResultListProps, 'placeholder' | 'itemRender'>;
    state: ResultListState;
    cancelSearch?: () => void;
    id: string;
    sortable?: Sortable;
    unmounted: boolean;
    componentDidMount(): void;
    componentDidUpdate(): void;
    componentWillUnmount(): void;
    initSortable(): void;
    desposeSortable(): void;
    handleValueChange(index: number, value: any, name: string): void;
    search(inputValue: string): void;
    clearSearch(): void;
    handleCloseItem(option: Option): void;
    renderNormalList(value?: Options): JSX.Element;
    render(): JSX.Element;
}
declare const _default: {
    new (props: Omit<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
        locale?: string | undefined;
        translate?: ((str: string, ...args: any[]) => string) | undefined;
    }, keyof ThemeProps> & import("../theme").ThemeOutterProps): {
        ref: any;
        childRef(ref: any): void;
        getWrappedInstance(): any;
        render(): JSX.Element;
        context: any;
        setState<K extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Omit<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>) => {} | Pick<{}, K> | null) | Pick<{}, K> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callback?: (() => void) | undefined): void;
        readonly props: Readonly<Omit<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps> & Readonly<{
            children?: React.ReactNode;
        }>;
        state: Readonly<{}>;
        refs: {
            [key: string]: React.ReactInstance;
        };
        componentDidMount?(): void;
        shouldComponentUpdate?(nextProps: Readonly<Omit<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextState: Readonly<{}>, nextContext: any): boolean;
        componentWillUnmount?(): void;
        componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
        getSnapshotBeforeUpdate?(prevProps: Readonly<Omit<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, prevState: Readonly<{}>): any;
        componentDidUpdate?(prevProps: Readonly<Omit<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, prevState: Readonly<{}>, snapshot?: any): void;
        componentWillMount?(): void;
        UNSAFE_componentWillMount?(): void;
        componentWillReceiveProps?(nextProps: Readonly<Omit<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextContext: any): void;
        UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Omit<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextContext: any): void;
        componentWillUpdate?(nextProps: Readonly<Omit<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextState: Readonly<{}>, nextContext: any): void;
        UNSAFE_componentWillUpdate?(nextProps: Readonly<Omit<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextState: Readonly<{}>, nextContext: any): void;
    };
    displayName: string;
    contextType: React.Context<string>;
    ComposedComponent: React.ComponentType<{
        new (props: Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }): {
            ref: any;
            childRef(ref: any): void;
            getWrappedInstance(): any;
            render(): JSX.Element;
            context: any;
            setState<K_1 extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>) => {} | Pick<{}, K_1> | null) | Pick<{}, K_1> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }> & Readonly<{
                children?: React.ReactNode;
            }>;
            state: Readonly<{}>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            componentDidMount?(): void;
            shouldComponentUpdate?(nextProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): boolean;
            componentWillUnmount?(): void;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>): any;
            componentDidUpdate?(prevProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
        };
        displayName: string;
        contextType: React.Context<string>;
        ComposedComponent: React.ComponentType<typeof ResultList>;
    } & import("hoist-non-react-statics").NonReactStatics<typeof ResultList, {}> & {
        ComposedComponent: typeof ResultList;
    }>;
} & import("hoist-non-react-statics").NonReactStatics<{
    new (props: Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
        locale?: string | undefined;
        translate?: ((str: string, ...args: any[]) => string) | undefined;
    }): {
        ref: any;
        childRef(ref: any): void;
        getWrappedInstance(): any;
        render(): JSX.Element;
        context: any;
        setState<K_1 extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>) => {} | Pick<{}, K_1> | null) | Pick<{}, K_1> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callback?: (() => void) | undefined): void;
        readonly props: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }> & Readonly<{
            children?: React.ReactNode;
        }>;
        state: Readonly<{}>;
        refs: {
            [key: string]: React.ReactInstance;
        };
        componentDidMount?(): void;
        shouldComponentUpdate?(nextProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextState: Readonly<{}>, nextContext: any): boolean;
        componentWillUnmount?(): void;
        componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
        getSnapshotBeforeUpdate?(prevProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, prevState: Readonly<{}>): any;
        componentDidUpdate?(prevProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, prevState: Readonly<{}>, snapshot?: any): void;
        componentWillMount?(): void;
        UNSAFE_componentWillMount?(): void;
        componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextContext: any): void;
        UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextContext: any): void;
        componentWillUpdate?(nextProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextState: Readonly<{}>, nextContext: any): void;
        UNSAFE_componentWillUpdate?(nextProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextState: Readonly<{}>, nextContext: any): void;
    };
    displayName: string;
    contextType: React.Context<string>;
    ComposedComponent: React.ComponentType<typeof ResultList>;
} & import("hoist-non-react-statics").NonReactStatics<typeof ResultList, {}> & {
    ComposedComponent: typeof ResultList;
}, {}> & {
    ComposedComponent: {
        new (props: Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }): {
            ref: any;
            childRef(ref: any): void;
            getWrappedInstance(): any;
            render(): JSX.Element;
            context: any;
            setState<K_1 extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>) => {} | Pick<{}, K_1> | null) | Pick<{}, K_1> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }> & Readonly<{
                children?: React.ReactNode;
            }>;
            state: Readonly<{}>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            componentDidMount?(): void;
            shouldComponentUpdate?(nextProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): boolean;
            componentWillUnmount?(): void;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>): any;
            componentDidUpdate?(prevProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<Pick<Omit<ResultListProps, keyof LocaleProps>, "classPrefix" | "classnames" | "title" | "className" | "theme" | "value" | "columns" | "disabled" | "multiple" | "onClick" | "options" | "inline" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "searchable" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender"> & Partial<Pick<Omit<ResultListProps, keyof LocaleProps>, "placeholder" | "itemRender">> & Partial<Pick<Pick<ResultListProps, "placeholder" | "itemRender">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
        };
        displayName: string;
        contextType: React.Context<string>;
        ComposedComponent: React.ComponentType<typeof ResultList>;
    } & import("hoist-non-react-statics").NonReactStatics<typeof ResultList, {}> & {
        ComposedComponent: typeof ResultList;
    };
};
export default _default;
