/// <reference types="lodash" />
/// <reference types="hoist-non-react-statics" />
import React from 'react';
import { ThemeProps } from '../theme';
import { BaseSelectionProps, ItemRenderStates } from './Selection';
import { Options, Option } from './Select';
import { LocaleProps } from '../locale';
import { ItemRenderStates as ResultItemRenderStates } from './ResultList';
export declare type SelectMode = 'table' | 'group' | 'list' | 'tree' | 'chained' | 'associated';
export interface TransferProps extends ThemeProps, LocaleProps, Omit<BaseSelectionProps, 'itemRender'> {
    inline?: boolean;
    statistics?: boolean;
    showArrow?: boolean;
    multiple?: boolean;
    selectTitle?: string;
    selectMode?: SelectMode;
    columns?: Array<{
        name: string;
        label: string;
        [propName: string]: any;
    }>;
    cellRender?: (column: {
        name: string;
        label: string;
        [propName: string]: any;
    }, option: Option, colIndex: number, rowIndex: number) => JSX.Element;
    leftOptions?: Array<Option>;
    leftMode?: 'tree' | 'list' | 'group';
    leftDefaultValue?: any;
    rightMode?: 'table' | 'list' | 'group' | 'tree' | 'chained';
    searchResultMode?: 'table' | 'list' | 'group' | 'tree' | 'chained';
    searchResultColumns?: Array<{
        name: string;
        label: string;
        [propName: string]: any;
    }>;
    searchPlaceholder?: string;
    noResultsText?: string;
    onChange?: (value: Array<Option>, optionModified?: boolean) => void;
    onSearch?: (term: string, setCancel: (cancel: () => void) => void) => Promise<Options | void>;
    selectRender?: (props: Omit<TransferProps, 'onSearch'> & {
        onSearch: (text: string) => void;
        onSearchCancel: () => void;
        searchResult: Options | null;
    }) => JSX.Element;
    resultTitle?: string;
    resultListModeFollowSelect?: boolean;
    resultSearchPlaceholder?: string;
    optionItemRender?: (option: Option, states: ItemRenderStates) => JSX.Element;
    resultItemRender?: (option: Option, states: ResultItemRenderStates) => JSX.Element;
    resultSearchable?: boolean;
    onResultSearch?: (text: string, item: Option) => boolean;
    sortable?: boolean;
    onRef?: (ref: Transfer) => void;
    onSelectAll?: (options: Options) => void;
}
export interface TransferState {
    inputValue: string;
    searchResult: Options | null;
    isTreeDeferLoad: boolean;
    resultSelectMode: 'list' | 'tree' | 'table';
}
export declare class Transfer<T extends TransferProps = TransferProps> extends React.Component<T, TransferState> {
    static defaultProps: Pick<TransferProps, 'multiple' | 'resultListModeFollowSelect' | 'selectMode'>;
    state: TransferState;
    valueArray: Options;
    availableOptions: Options;
    unmounted: boolean;
    cancelSearch?: () => void;
    treeRef: any;
    componentDidMount(): void;
    static getDerivedStateFromProps(props: TransferProps): {
        isTreeDeferLoad: boolean;
        resultSelectMode: string;
    };
    componentWillUnmount(): void;
    domRef(ref: any): void;
    toggleAll(): void;
    selectAll(): void;
    clearAll(): void;
    handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
    handleSearch(inputValue: string): void;
    handleSeachCancel(): void;
    lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
    getFlattenArr(options: Array<Option>): Option[];
    handleSearchTreeChange(values: Array<Option>, searchOptions: Array<Option>): void;
    renderSelect(props: TransferProps & {
        onToggleAll?: () => void;
    }): JSX.Element;
    renderSearchResult(props: TransferProps): JSX.Element;
    renderOptions(props: TransferProps): JSX.Element;
    renderResult(): JSX.Element;
    render(): JSX.Element;
}
declare const _default: {
    new (props: Omit<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
        locale?: string | undefined;
        translate?: ((str: string, ...args: any[]) => string) | undefined;
    }, keyof ThemeProps> & import("../theme").ThemeOutterProps): {
        ref: any;
        childRef(ref: any): void;
        getWrappedInstance(): any;
        render(): JSX.Element;
        context: any;
        setState<K extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Omit<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>) => {} | Pick<{}, K> | null) | Pick<{}, K> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callback?: (() => void) | undefined): void;
        readonly props: Readonly<Omit<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps> & Readonly<{
            children?: React.ReactNode;
        }>;
        state: Readonly<{}>;
        refs: {
            [key: string]: React.ReactInstance;
        };
        componentDidMount?(): void;
        shouldComponentUpdate?(nextProps: Readonly<Omit<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextState: Readonly<{}>, nextContext: any): boolean;
        componentWillUnmount?(): void;
        componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
        getSnapshotBeforeUpdate?(prevProps: Readonly<Omit<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, prevState: Readonly<{}>): any;
        componentDidUpdate?(prevProps: Readonly<Omit<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, prevState: Readonly<{}>, snapshot?: any): void;
        componentWillMount?(): void;
        UNSAFE_componentWillMount?(): void;
        componentWillReceiveProps?(nextProps: Readonly<Omit<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextContext: any): void;
        UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Omit<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextContext: any): void;
        componentWillUpdate?(nextProps: Readonly<Omit<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextState: Readonly<{}>, nextContext: any): void;
        UNSAFE_componentWillUpdate?(nextProps: Readonly<Omit<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }, keyof ThemeProps> & import("../theme").ThemeOutterProps>, nextState: Readonly<{}>, nextContext: any): void;
    };
    displayName: string;
    contextType: React.Context<string>;
    ComposedComponent: React.ComponentType<{
        new (props: Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }): {
            ref: any;
            childRef(ref: any): void;
            getWrappedInstance(): any;
            render(): JSX.Element;
            context: any;
            setState<K_1 extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>) => {} | Pick<{}, K_1> | null) | Pick<{}, K_1> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }> & Readonly<{
                children?: React.ReactNode;
            }>;
            state: Readonly<{}>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            componentDidMount?(): void;
            shouldComponentUpdate?(nextProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): boolean;
            componentWillUnmount?(): void;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>): any;
            componentDidUpdate?(prevProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
        };
        displayName: string;
        contextType: React.Context<string>;
        ComposedComponent: React.ComponentType<{
            new (props: TransferProps | Readonly<TransferProps>): {
                state: TransferState;
                valueArray: Options;
                availableOptions: Options;
                unmounted: boolean;
                cancelSearch?: (() => void) | undefined;
                treeRef: any;
                componentDidMount(): void;
                componentWillUnmount(): void;
                domRef(ref: any): void;
                toggleAll(): void;
                selectAll(): void;
                clearAll(): void;
                handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
                handleSearch(inputValue: string): void;
                handleSeachCancel(): void;
                lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
                getFlattenArr(options: Option[]): Option[];
                handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
                renderSelect(props: TransferProps & {
                    onToggleAll?: (() => void) | undefined;
                }): JSX.Element;
                renderSearchResult(props: TransferProps): JSX.Element;
                renderOptions(props: TransferProps): JSX.Element;
                renderResult(): JSX.Element;
                render(): JSX.Element;
                context: any;
                setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
                forceUpdate(callback?: (() => void) | undefined): void;
                readonly props: Readonly<TransferProps> & Readonly<{
                    children?: React.ReactNode;
                }>;
                refs: {
                    [key: string]: React.ReactInstance;
                };
                shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
                componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
                getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
                componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
                componentWillMount?(): void;
                UNSAFE_componentWillMount?(): void;
                componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
                UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            };
            new (props: TransferProps, context: any): {
                state: TransferState;
                valueArray: Options;
                availableOptions: Options;
                unmounted: boolean;
                cancelSearch?: (() => void) | undefined;
                treeRef: any;
                componentDidMount(): void;
                componentWillUnmount(): void;
                domRef(ref: any): void;
                toggleAll(): void;
                selectAll(): void;
                clearAll(): void;
                handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
                handleSearch(inputValue: string): void;
                handleSeachCancel(): void;
                lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
                getFlattenArr(options: Option[]): Option[];
                handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
                renderSelect(props: TransferProps & {
                    onToggleAll?: (() => void) | undefined;
                }): JSX.Element;
                renderSearchResult(props: TransferProps): JSX.Element;
                renderOptions(props: TransferProps): JSX.Element;
                renderResult(): JSX.Element;
                render(): JSX.Element;
                context: any;
                setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
                forceUpdate(callback?: (() => void) | undefined): void;
                readonly props: Readonly<TransferProps> & Readonly<{
                    children?: React.ReactNode;
                }>;
                refs: {
                    [key: string]: React.ReactInstance;
                };
                shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
                componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
                getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
                componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
                componentWillMount?(): void;
                UNSAFE_componentWillMount?(): void;
                componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
                UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            };
            defaultProps: Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">;
            getDerivedStateFromProps(props: TransferProps): {
                isTreeDeferLoad: boolean;
                resultSelectMode: string;
            };
            contextType?: React.Context<any> | undefined;
        }>;
    } & import("hoist-non-react-statics").NonReactStatics<{
        new (props: TransferProps | Readonly<TransferProps>): {
            state: TransferState;
            valueArray: Options;
            availableOptions: Options;
            unmounted: boolean;
            cancelSearch?: (() => void) | undefined;
            treeRef: any;
            componentDidMount(): void;
            componentWillUnmount(): void;
            domRef(ref: any): void;
            toggleAll(): void;
            selectAll(): void;
            clearAll(): void;
            handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
            handleSearch(inputValue: string): void;
            handleSeachCancel(): void;
            lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
            getFlattenArr(options: Option[]): Option[];
            handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
            renderSelect(props: TransferProps & {
                onToggleAll?: (() => void) | undefined;
            }): JSX.Element;
            renderSearchResult(props: TransferProps): JSX.Element;
            renderOptions(props: TransferProps): JSX.Element;
            renderResult(): JSX.Element;
            render(): JSX.Element;
            context: any;
            setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<TransferProps> & Readonly<{
                children?: React.ReactNode;
            }>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
            componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
        };
        new (props: TransferProps, context: any): {
            state: TransferState;
            valueArray: Options;
            availableOptions: Options;
            unmounted: boolean;
            cancelSearch?: (() => void) | undefined;
            treeRef: any;
            componentDidMount(): void;
            componentWillUnmount(): void;
            domRef(ref: any): void;
            toggleAll(): void;
            selectAll(): void;
            clearAll(): void;
            handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
            handleSearch(inputValue: string): void;
            handleSeachCancel(): void;
            lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
            getFlattenArr(options: Option[]): Option[];
            handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
            renderSelect(props: TransferProps & {
                onToggleAll?: (() => void) | undefined;
            }): JSX.Element;
            renderSearchResult(props: TransferProps): JSX.Element;
            renderOptions(props: TransferProps): JSX.Element;
            renderResult(): JSX.Element;
            render(): JSX.Element;
            context: any;
            setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<TransferProps> & Readonly<{
                children?: React.ReactNode;
            }>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
            componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
        };
        defaultProps: Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">;
        getDerivedStateFromProps(props: TransferProps): {
            isTreeDeferLoad: boolean;
            resultSelectMode: string;
        };
        contextType?: React.Context<any> | undefined;
    }, {}> & {
        ComposedComponent: {
            new (props: TransferProps | Readonly<TransferProps>): {
                state: TransferState;
                valueArray: Options;
                availableOptions: Options;
                unmounted: boolean;
                cancelSearch?: (() => void) | undefined;
                treeRef: any;
                componentDidMount(): void;
                componentWillUnmount(): void;
                domRef(ref: any): void;
                toggleAll(): void;
                selectAll(): void;
                clearAll(): void;
                handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
                handleSearch(inputValue: string): void;
                handleSeachCancel(): void;
                lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
                getFlattenArr(options: Option[]): Option[];
                handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
                renderSelect(props: TransferProps & {
                    onToggleAll?: (() => void) | undefined;
                }): JSX.Element;
                renderSearchResult(props: TransferProps): JSX.Element;
                renderOptions(props: TransferProps): JSX.Element;
                renderResult(): JSX.Element;
                render(): JSX.Element;
                context: any;
                setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
                forceUpdate(callback?: (() => void) | undefined): void;
                readonly props: Readonly<TransferProps> & Readonly<{
                    children?: React.ReactNode;
                }>;
                refs: {
                    [key: string]: React.ReactInstance;
                };
                shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
                componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
                getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
                componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
                componentWillMount?(): void;
                UNSAFE_componentWillMount?(): void;
                componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
                UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            };
            new (props: TransferProps, context: any): {
                state: TransferState;
                valueArray: Options;
                availableOptions: Options;
                unmounted: boolean;
                cancelSearch?: (() => void) | undefined;
                treeRef: any;
                componentDidMount(): void;
                componentWillUnmount(): void;
                domRef(ref: any): void;
                toggleAll(): void;
                selectAll(): void;
                clearAll(): void;
                handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
                handleSearch(inputValue: string): void;
                handleSeachCancel(): void;
                lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
                getFlattenArr(options: Option[]): Option[];
                handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
                renderSelect(props: TransferProps & {
                    onToggleAll?: (() => void) | undefined;
                }): JSX.Element;
                renderSearchResult(props: TransferProps): JSX.Element;
                renderOptions(props: TransferProps): JSX.Element;
                renderResult(): JSX.Element;
                render(): JSX.Element;
                context: any;
                setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
                forceUpdate(callback?: (() => void) | undefined): void;
                readonly props: Readonly<TransferProps> & Readonly<{
                    children?: React.ReactNode;
                }>;
                refs: {
                    [key: string]: React.ReactInstance;
                };
                shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
                componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
                getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
                componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
                componentWillMount?(): void;
                UNSAFE_componentWillMount?(): void;
                componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
                UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            };
            defaultProps: Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">;
            getDerivedStateFromProps(props: TransferProps): {
                isTreeDeferLoad: boolean;
                resultSelectMode: string;
            };
            contextType?: React.Context<any> | undefined;
        };
    }>;
} & import("hoist-non-react-statics").NonReactStatics<{
    new (props: Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
        locale?: string | undefined;
        translate?: ((str: string, ...args: any[]) => string) | undefined;
    }): {
        ref: any;
        childRef(ref: any): void;
        getWrappedInstance(): any;
        render(): JSX.Element;
        context: any;
        setState<K_1 extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>) => {} | Pick<{}, K_1> | null) | Pick<{}, K_1> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callback?: (() => void) | undefined): void;
        readonly props: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }> & Readonly<{
            children?: React.ReactNode;
        }>;
        state: Readonly<{}>;
        refs: {
            [key: string]: React.ReactInstance;
        };
        componentDidMount?(): void;
        shouldComponentUpdate?(nextProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextState: Readonly<{}>, nextContext: any): boolean;
        componentWillUnmount?(): void;
        componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
        getSnapshotBeforeUpdate?(prevProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, prevState: Readonly<{}>): any;
        componentDidUpdate?(prevProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, prevState: Readonly<{}>, snapshot?: any): void;
        componentWillMount?(): void;
        UNSAFE_componentWillMount?(): void;
        componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextContext: any): void;
        UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextContext: any): void;
        componentWillUpdate?(nextProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextState: Readonly<{}>, nextContext: any): void;
        UNSAFE_componentWillUpdate?(nextProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }>, nextState: Readonly<{}>, nextContext: any): void;
    };
    displayName: string;
    contextType: React.Context<string>;
    ComposedComponent: React.ComponentType<{
        new (props: TransferProps | Readonly<TransferProps>): {
            state: TransferState;
            valueArray: Options;
            availableOptions: Options;
            unmounted: boolean;
            cancelSearch?: (() => void) | undefined;
            treeRef: any;
            componentDidMount(): void;
            componentWillUnmount(): void;
            domRef(ref: any): void;
            toggleAll(): void;
            selectAll(): void;
            clearAll(): void;
            handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
            handleSearch(inputValue: string): void;
            handleSeachCancel(): void;
            lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
            getFlattenArr(options: Option[]): Option[];
            handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
            renderSelect(props: TransferProps & {
                onToggleAll?: (() => void) | undefined;
            }): JSX.Element;
            renderSearchResult(props: TransferProps): JSX.Element;
            renderOptions(props: TransferProps): JSX.Element;
            renderResult(): JSX.Element;
            render(): JSX.Element;
            context: any;
            setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<TransferProps> & Readonly<{
                children?: React.ReactNode;
            }>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
            componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
        };
        new (props: TransferProps, context: any): {
            state: TransferState;
            valueArray: Options;
            availableOptions: Options;
            unmounted: boolean;
            cancelSearch?: (() => void) | undefined;
            treeRef: any;
            componentDidMount(): void;
            componentWillUnmount(): void;
            domRef(ref: any): void;
            toggleAll(): void;
            selectAll(): void;
            clearAll(): void;
            handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
            handleSearch(inputValue: string): void;
            handleSeachCancel(): void;
            lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
            getFlattenArr(options: Option[]): Option[];
            handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
            renderSelect(props: TransferProps & {
                onToggleAll?: (() => void) | undefined;
            }): JSX.Element;
            renderSearchResult(props: TransferProps): JSX.Element;
            renderOptions(props: TransferProps): JSX.Element;
            renderResult(): JSX.Element;
            render(): JSX.Element;
            context: any;
            setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<TransferProps> & Readonly<{
                children?: React.ReactNode;
            }>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
            componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
        };
        defaultProps: Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">;
        getDerivedStateFromProps(props: TransferProps): {
            isTreeDeferLoad: boolean;
            resultSelectMode: string;
        };
        contextType?: React.Context<any> | undefined;
    }>;
} & import("hoist-non-react-statics").NonReactStatics<{
    new (props: TransferProps | Readonly<TransferProps>): {
        state: TransferState;
        valueArray: Options;
        availableOptions: Options;
        unmounted: boolean;
        cancelSearch?: (() => void) | undefined;
        treeRef: any;
        componentDidMount(): void;
        componentWillUnmount(): void;
        domRef(ref: any): void;
        toggleAll(): void;
        selectAll(): void;
        clearAll(): void;
        handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
        handleSearch(inputValue: string): void;
        handleSeachCancel(): void;
        lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
        getFlattenArr(options: Option[]): Option[];
        handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
        renderSelect(props: TransferProps & {
            onToggleAll?: (() => void) | undefined;
        }): JSX.Element;
        renderSearchResult(props: TransferProps): JSX.Element;
        renderOptions(props: TransferProps): JSX.Element;
        renderResult(): JSX.Element;
        render(): JSX.Element;
        context: any;
        setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callback?: (() => void) | undefined): void;
        readonly props: Readonly<TransferProps> & Readonly<{
            children?: React.ReactNode;
        }>;
        refs: {
            [key: string]: React.ReactInstance;
        };
        shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
        componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
        getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
        componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
        componentWillMount?(): void;
        UNSAFE_componentWillMount?(): void;
        componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
        UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
        componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
        UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
    };
    new (props: TransferProps, context: any): {
        state: TransferState;
        valueArray: Options;
        availableOptions: Options;
        unmounted: boolean;
        cancelSearch?: (() => void) | undefined;
        treeRef: any;
        componentDidMount(): void;
        componentWillUnmount(): void;
        domRef(ref: any): void;
        toggleAll(): void;
        selectAll(): void;
        clearAll(): void;
        handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
        handleSearch(inputValue: string): void;
        handleSeachCancel(): void;
        lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
        getFlattenArr(options: Option[]): Option[];
        handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
        renderSelect(props: TransferProps & {
            onToggleAll?: (() => void) | undefined;
        }): JSX.Element;
        renderSearchResult(props: TransferProps): JSX.Element;
        renderOptions(props: TransferProps): JSX.Element;
        renderResult(): JSX.Element;
        render(): JSX.Element;
        context: any;
        setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
        forceUpdate(callback?: (() => void) | undefined): void;
        readonly props: Readonly<TransferProps> & Readonly<{
            children?: React.ReactNode;
        }>;
        refs: {
            [key: string]: React.ReactInstance;
        };
        shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
        componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
        getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
        componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
        componentWillMount?(): void;
        UNSAFE_componentWillMount?(): void;
        componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
        UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
        componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
        UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
    };
    defaultProps: Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">;
    getDerivedStateFromProps(props: TransferProps): {
        isTreeDeferLoad: boolean;
        resultSelectMode: string;
    };
    contextType?: React.Context<any> | undefined;
}, {}> & {
    ComposedComponent: {
        new (props: TransferProps | Readonly<TransferProps>): {
            state: TransferState;
            valueArray: Options;
            availableOptions: Options;
            unmounted: boolean;
            cancelSearch?: (() => void) | undefined;
            treeRef: any;
            componentDidMount(): void;
            componentWillUnmount(): void;
            domRef(ref: any): void;
            toggleAll(): void;
            selectAll(): void;
            clearAll(): void;
            handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
            handleSearch(inputValue: string): void;
            handleSeachCancel(): void;
            lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
            getFlattenArr(options: Option[]): Option[];
            handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
            renderSelect(props: TransferProps & {
                onToggleAll?: (() => void) | undefined;
            }): JSX.Element;
            renderSearchResult(props: TransferProps): JSX.Element;
            renderOptions(props: TransferProps): JSX.Element;
            renderResult(): JSX.Element;
            render(): JSX.Element;
            context: any;
            setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<TransferProps> & Readonly<{
                children?: React.ReactNode;
            }>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
            componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
        };
        new (props: TransferProps, context: any): {
            state: TransferState;
            valueArray: Options;
            availableOptions: Options;
            unmounted: boolean;
            cancelSearch?: (() => void) | undefined;
            treeRef: any;
            componentDidMount(): void;
            componentWillUnmount(): void;
            domRef(ref: any): void;
            toggleAll(): void;
            selectAll(): void;
            clearAll(): void;
            handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
            handleSearch(inputValue: string): void;
            handleSeachCancel(): void;
            lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
            getFlattenArr(options: Option[]): Option[];
            handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
            renderSelect(props: TransferProps & {
                onToggleAll?: (() => void) | undefined;
            }): JSX.Element;
            renderSearchResult(props: TransferProps): JSX.Element;
            renderOptions(props: TransferProps): JSX.Element;
            renderResult(): JSX.Element;
            render(): JSX.Element;
            context: any;
            setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<TransferProps> & Readonly<{
                children?: React.ReactNode;
            }>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
            componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
        };
        defaultProps: Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">;
        getDerivedStateFromProps(props: TransferProps): {
            isTreeDeferLoad: boolean;
            resultSelectMode: string;
        };
        contextType?: React.Context<any> | undefined;
    };
}, {}> & {
    ComposedComponent: {
        new (props: Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
            locale?: string | undefined;
            translate?: ((str: string, ...args: any[]) => string) | undefined;
        }): {
            ref: any;
            childRef(ref: any): void;
            getWrappedInstance(): any;
            render(): JSX.Element;
            context: any;
            setState<K_1 extends never>(state: {} | ((prevState: Readonly<{}>, props: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>) => {} | Pick<{}, K_1> | null) | Pick<{}, K_1> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }> & Readonly<{
                children?: React.ReactNode;
            }>;
            state: Readonly<{}>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            componentDidMount?(): void;
            shouldComponentUpdate?(nextProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): boolean;
            componentWillUnmount?(): void;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>): any;
            componentDidUpdate?(prevProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, prevState: Readonly<{}>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<Pick<Omit<TransferProps, keyof LocaleProps>, "classPrefix" | "classnames" | "className" | "theme" | "value" | "columns" | "disabled" | "onClick" | "options" | "inline" | "showArrow" | "placeholder" | "onChange" | "itemClassName" | "labelClassName" | "clearable" | "sortable" | "leftOptions" | "leftMode" | "rightMode" | "searchResultMode" | "searchResultColumns" | "resultSearchable" | "selectTitle" | "resultTitle" | "searchPlaceholder" | "resultSearchPlaceholder" | "onRef" | "noResultsText" | "statistics" | "onSearch" | "onDeferLoad" | "onLeftDeferLoad" | "option2value" | "cellRender" | "leftDefaultValue" | "selectRender" | "optionItemRender" | "resultItemRender" | "onResultSearch" | "onSelectAll"> & Partial<Pick<Omit<TransferProps, keyof LocaleProps>, "multiple" | "selectMode" | "resultListModeFollowSelect">> & Partial<Pick<Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">, never>> & {
                locale?: string | undefined;
                translate?: ((str: string, ...args: any[]) => string) | undefined;
            }>, nextState: Readonly<{}>, nextContext: any): void;
        };
        displayName: string;
        contextType: React.Context<string>;
        ComposedComponent: React.ComponentType<{
            new (props: TransferProps | Readonly<TransferProps>): {
                state: TransferState;
                valueArray: Options;
                availableOptions: Options;
                unmounted: boolean;
                cancelSearch?: (() => void) | undefined;
                treeRef: any;
                componentDidMount(): void;
                componentWillUnmount(): void;
                domRef(ref: any): void;
                toggleAll(): void;
                selectAll(): void;
                clearAll(): void;
                handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
                handleSearch(inputValue: string): void;
                handleSeachCancel(): void;
                lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
                getFlattenArr(options: Option[]): Option[];
                handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
                renderSelect(props: TransferProps & {
                    onToggleAll?: (() => void) | undefined;
                }): JSX.Element;
                renderSearchResult(props: TransferProps): JSX.Element;
                renderOptions(props: TransferProps): JSX.Element;
                renderResult(): JSX.Element;
                render(): JSX.Element;
                context: any;
                setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
                forceUpdate(callback?: (() => void) | undefined): void;
                readonly props: Readonly<TransferProps> & Readonly<{
                    children?: React.ReactNode;
                }>;
                refs: {
                    [key: string]: React.ReactInstance;
                };
                shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
                componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
                getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
                componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
                componentWillMount?(): void;
                UNSAFE_componentWillMount?(): void;
                componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
                UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            };
            new (props: TransferProps, context: any): {
                state: TransferState;
                valueArray: Options;
                availableOptions: Options;
                unmounted: boolean;
                cancelSearch?: (() => void) | undefined;
                treeRef: any;
                componentDidMount(): void;
                componentWillUnmount(): void;
                domRef(ref: any): void;
                toggleAll(): void;
                selectAll(): void;
                clearAll(): void;
                handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
                handleSearch(inputValue: string): void;
                handleSeachCancel(): void;
                lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
                getFlattenArr(options: Option[]): Option[];
                handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
                renderSelect(props: TransferProps & {
                    onToggleAll?: (() => void) | undefined;
                }): JSX.Element;
                renderSearchResult(props: TransferProps): JSX.Element;
                renderOptions(props: TransferProps): JSX.Element;
                renderResult(): JSX.Element;
                render(): JSX.Element;
                context: any;
                setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
                forceUpdate(callback?: (() => void) | undefined): void;
                readonly props: Readonly<TransferProps> & Readonly<{
                    children?: React.ReactNode;
                }>;
                refs: {
                    [key: string]: React.ReactInstance;
                };
                shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
                componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
                getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
                componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
                componentWillMount?(): void;
                UNSAFE_componentWillMount?(): void;
                componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
                UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            };
            defaultProps: Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">;
            getDerivedStateFromProps(props: TransferProps): {
                isTreeDeferLoad: boolean;
                resultSelectMode: string;
            };
            contextType?: React.Context<any> | undefined;
        }>;
    } & import("hoist-non-react-statics").NonReactStatics<{
        new (props: TransferProps | Readonly<TransferProps>): {
            state: TransferState;
            valueArray: Options;
            availableOptions: Options;
            unmounted: boolean;
            cancelSearch?: (() => void) | undefined;
            treeRef: any;
            componentDidMount(): void;
            componentWillUnmount(): void;
            domRef(ref: any): void;
            toggleAll(): void;
            selectAll(): void;
            clearAll(): void;
            handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
            handleSearch(inputValue: string): void;
            handleSeachCancel(): void;
            lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
            getFlattenArr(options: Option[]): Option[];
            handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
            renderSelect(props: TransferProps & {
                onToggleAll?: (() => void) | undefined;
            }): JSX.Element;
            renderSearchResult(props: TransferProps): JSX.Element;
            renderOptions(props: TransferProps): JSX.Element;
            renderResult(): JSX.Element;
            render(): JSX.Element;
            context: any;
            setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<TransferProps> & Readonly<{
                children?: React.ReactNode;
            }>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
            componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
        };
        new (props: TransferProps, context: any): {
            state: TransferState;
            valueArray: Options;
            availableOptions: Options;
            unmounted: boolean;
            cancelSearch?: (() => void) | undefined;
            treeRef: any;
            componentDidMount(): void;
            componentWillUnmount(): void;
            domRef(ref: any): void;
            toggleAll(): void;
            selectAll(): void;
            clearAll(): void;
            handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
            handleSearch(inputValue: string): void;
            handleSeachCancel(): void;
            lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
            getFlattenArr(options: Option[]): Option[];
            handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
            renderSelect(props: TransferProps & {
                onToggleAll?: (() => void) | undefined;
            }): JSX.Element;
            renderSearchResult(props: TransferProps): JSX.Element;
            renderOptions(props: TransferProps): JSX.Element;
            renderResult(): JSX.Element;
            render(): JSX.Element;
            context: any;
            setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
            forceUpdate(callback?: (() => void) | undefined): void;
            readonly props: Readonly<TransferProps> & Readonly<{
                children?: React.ReactNode;
            }>;
            refs: {
                [key: string]: React.ReactInstance;
            };
            shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
            componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
            getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
            componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
            componentWillMount?(): void;
            UNSAFE_componentWillMount?(): void;
            componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
            componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
        };
        defaultProps: Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">;
        getDerivedStateFromProps(props: TransferProps): {
            isTreeDeferLoad: boolean;
            resultSelectMode: string;
        };
        contextType?: React.Context<any> | undefined;
    }, {}> & {
        ComposedComponent: {
            new (props: TransferProps | Readonly<TransferProps>): {
                state: TransferState;
                valueArray: Options;
                availableOptions: Options;
                unmounted: boolean;
                cancelSearch?: (() => void) | undefined;
                treeRef: any;
                componentDidMount(): void;
                componentWillUnmount(): void;
                domRef(ref: any): void;
                toggleAll(): void;
                selectAll(): void;
                clearAll(): void;
                handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
                handleSearch(inputValue: string): void;
                handleSeachCancel(): void;
                lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
                getFlattenArr(options: Option[]): Option[];
                handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
                renderSelect(props: TransferProps & {
                    onToggleAll?: (() => void) | undefined;
                }): JSX.Element;
                renderSearchResult(props: TransferProps): JSX.Element;
                renderOptions(props: TransferProps): JSX.Element;
                renderResult(): JSX.Element;
                render(): JSX.Element;
                context: any;
                setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
                forceUpdate(callback?: (() => void) | undefined): void;
                readonly props: Readonly<TransferProps> & Readonly<{
                    children?: React.ReactNode;
                }>;
                refs: {
                    [key: string]: React.ReactInstance;
                };
                shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
                componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
                getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
                componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
                componentWillMount?(): void;
                UNSAFE_componentWillMount?(): void;
                componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
                UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            };
            new (props: TransferProps, context: any): {
                state: TransferState;
                valueArray: Options;
                availableOptions: Options;
                unmounted: boolean;
                cancelSearch?: (() => void) | undefined;
                treeRef: any;
                componentDidMount(): void;
                componentWillUnmount(): void;
                domRef(ref: any): void;
                toggleAll(): void;
                selectAll(): void;
                clearAll(): void;
                handleSearchKeyDown(e: React.KeyboardEvent<any>): void;
                handleSearch(inputValue: string): void;
                handleSeachCancel(): void;
                lazySearch: import("lodash").DebouncedFunc<() => Promise<void>>;
                getFlattenArr(options: Option[]): Option[];
                handleSearchTreeChange(values: Option[], searchOptions: Option[]): void;
                renderSelect(props: TransferProps & {
                    onToggleAll?: (() => void) | undefined;
                }): JSX.Element;
                renderSearchResult(props: TransferProps): JSX.Element;
                renderOptions(props: TransferProps): JSX.Element;
                renderResult(): JSX.Element;
                render(): JSX.Element;
                context: any;
                setState<K_2 extends keyof TransferState>(state: TransferState | ((prevState: Readonly<TransferState>, props: Readonly<TransferProps>) => TransferState | Pick<TransferState, K_2> | null) | Pick<TransferState, K_2> | null, callback?: (() => void) | undefined): void;
                forceUpdate(callback?: (() => void) | undefined): void;
                readonly props: Readonly<TransferProps> & Readonly<{
                    children?: React.ReactNode;
                }>;
                refs: {
                    [key: string]: React.ReactInstance;
                };
                shouldComponentUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): boolean;
                componentDidCatch?(error: Error, errorInfo: React.ErrorInfo): void;
                getSnapshotBeforeUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>): any;
                componentDidUpdate?(prevProps: Readonly<TransferProps>, prevState: Readonly<TransferState>, snapshot?: any): void;
                componentWillMount?(): void;
                UNSAFE_componentWillMount?(): void;
                componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                UNSAFE_componentWillReceiveProps?(nextProps: Readonly<TransferProps>, nextContext: any): void;
                componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
                UNSAFE_componentWillUpdate?(nextProps: Readonly<TransferProps>, nextState: Readonly<TransferState>, nextContext: any): void;
            };
            defaultProps: Pick<TransferProps, "multiple" | "selectMode" | "resultListModeFollowSelect">;
            getDerivedStateFromProps(props: TransferProps): {
                isTreeDeferLoad: boolean;
                resultSelectMode: string;
            };
            contextType?: React.Context<any> | undefined;
        };
    };
};
export default _default;
